"use strict";
// MIT License
//
// Copyright (c) 2023 Douglas Nassif Roma Junior
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AnimationContext = void 0;
const react_1 = __importStar(require("react"));
const react_native_1 = require("react-native");
exports.AnimationContext = react_1.default.createContext(undefined);
const AnimationProvider = ({ children, animating = true, }) => {
    const [animations, setAnimations] = (0, react_1.useState)({});
    const registerAnimation = (0, react_1.useCallback)((animationId, animation) => {
        setAnimations(prev => {
            const copy = { ...prev };
            if (animation) {
                copy[animationId] = animation;
            }
            else {
                delete copy[animationId];
            }
            return copy;
        });
    }, []);
    (0, react_1.useEffect)(() => {
        if (!animating) {
            return undefined;
        }
        const animationValues = Object.values(animations);
        if (!animationValues.length) {
            return undefined;
        }
        const animation = react_native_1.Animated.loop(react_native_1.Animated.parallel(animationValues, {
            stopTogether: true,
        }));
        animation.start();
        return () => {
            animation.stop();
        };
    }, [animations, animating]);
    const animatedValue = (0, react_1.useMemo)(() => ({
        registerAnimation,
    }), [registerAnimation]);
    return (react_1.default.createElement(exports.AnimationContext.Provider, { value: animatedValue }, children));
};
exports.default = AnimationProvider;
//# sourceMappingURL=AnimationProvider.js.map